==> xcsoar-6.8.4.tar.xz: xcsoar-6.8.4/src/Units/System.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2015 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef XCSOAR_UNITS_SYSTEM_HPP
#define XCSOAR_UNITS_SYSTEM_HPP

#include "Unit.hpp"
#include "Math/fixed.hpp"
#include "Compiler.h"

namespace Units
{
  /**
   * Converts a value from the system unit to the user-specified unit
   * @param value The value in system unit
   * @param Unit The destination unit
   * @return The value in user-specified unit
   */
  gcc_const
  fixed ToUserUnit(fixed value, Unit unit);

  /**
   * Converts a value from the user-specified unit to the system unit
   * @param value The value in user-specified unit
   * @param Unit The source unit
   * @return The value in system unit
   */
  gcc_const
  fixed ToSysUnit(fixed value, Unit unit);
};

#endif

==> xcsoar-7.14.tar.xz: xcsoar-7.14/src/Units/System.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2021 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef XCSOAR_UNITS_SYSTEM_HPP
#define XCSOAR_UNITS_SYSTEM_HPP

#include "Unit.hpp"
#include "util/Compiler.h"

namespace Units
{
  /**
   * Converts a value from the system unit to the user-specified unit
   * @param value The value in system unit
   * @param Unit The destination unit
   * @return The value in user-specified unit
   */
  gcc_const
  double ToUserUnit(double value, Unit unit);

  /**
   * Converts a value from the user-specified unit to the system unit
   * @param value The value in user-specified unit
   * @param Unit The source unit
   * @return The value in system unit
   */
  gcc_const
  double ToSysUnit(double value, Unit unit);
};

#endif
